==> hs-glib-0.12.3.1_1.tbz: lib/ghc-7.4.1/cabal/glib-0.12.3.1/register.sh <==
#!/bin/sh
echo 'name: glib
version: 0.12.3.1
id: glib-0.12.3.1-b8fe1b8554ac9f9afc9af7e353ede55d

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the GLIB library for Gtk2Hs.
description: The GNU Library is a collection of C data structures and utility
             function for dealing with Unicode. This package only binds as
             much functionality as required to support the packages that
             wrap libraries that are themselves based on GLib.
category: System
author: Axel Simon, Duncan Coutts
exposed: True
exposed-modules: System.Glib System.Glib.GError
                 System.Glib.Properties System.Glib.Attributes System.Glib.Signals
                 System.Glib.MainLoop System.Glib.GDateTime System.Glib.GObject
                 System.Glib.Utils System.Glib.StoreValue System.Glib.FFI
                 System.Glib.Flags System.Glib.UTFString System.Glib.Types
                 System.Glib.GList System.Glib.GString System.Glib.GType
                 System.Glib.GTypeConstants System.Glib.GValue
                 System.Glib.GValueTypes System.Glib.GParameter
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/glib-0.12.3.1
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/glib-0.12.3.1
              /usr/local/lib
hs-libraries: HSglib-0.12.3.1
extra-libraries: gobject-2.0 gthread-2.0 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/glib-2.0
includes:
depends: base-4.5.0.0-3459bca6d8e46666b517e8bb2e033728
         containers-0.4.2.1-cfc6420ecc2194c9ed977b06bdfd9e69
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/glib-0.12.3.1/html/glib.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/glib-0.12.3.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-glib-0.12.4_1.tbz: lib/ghc-7.4.2/cabal/glib-0.12.4/register.sh <==
#!/bin/sh
echo 'name: glib
version: 0.12.4
id: glib-0.12.4-dc7ab9255cefef81913c196fd3b53d89

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the GLIB library for Gtk2Hs.
description: The GNU Library is a collection of C data structures and utility
             function for dealing with Unicode. This package only binds as
             much functionality as required to support the packages that
             wrap libraries that are themselves based on GLib.
category: System
author: Axel Simon, Duncan Coutts
exposed: True
exposed-modules: System.Glib System.Glib.GError
                 System.Glib.Properties System.Glib.Attributes System.Glib.Signals
                 System.Glib.MainLoop System.Glib.GDateTime System.Glib.GObject
                 System.Glib.Utils System.Glib.StoreValue System.Glib.FFI
                 System.Glib.Flags System.Glib.UTFString System.Glib.Types
                 System.Glib.GList System.Glib.GString System.Glib.GType
                 System.Glib.GTypeConstants System.Glib.GValue
                 System.Glib.GValueTypes System.Glib.GParameter
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/glib-0.12.4
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/glib-0.12.4
              /usr/local/lib
hs-libraries: HSglib-0.12.4
extra-libraries: gobject-2.0 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/glib-2.0
includes:
depends: base-4.5.1.0-12fddc14a7babb909dd3843e453b5660
         containers-0.4.2.1-efa59805336a77490296ae3897cecb87
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/glib-0.12.4/html/glib.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/glib-0.12.4/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
